@@ -1,17 +1,14 @@
 import torch
-import pickle
+
 def rangeBlock(block, vmin=0, vmax=5):
     loss = torch.arange(vmin, vmax, (vmax - vmin) / block, requires_grad=False).unsqueeze(dim=1)
     return loss
 
-
-
-# DataFrame
 def columnRename(df, ns):
     for n in ns:
         if n[0] in df.columns:
             df.rename(columns = {n[0]: n[1]}, inplace = True)
-#     columnRemove(df, ['CON밸브A','CON밸브A연산값','CON밸브B','CON밸브개도','CON밸브연산값'])
+#     columnRemove(df, ['c1', 'c2' ... ])
 
 
 def columnRemove(df, ns):
@@ -20,6 +17,11 @@ def columnRemove(df, ns):
         if n in df.columns:
             delList.append(n)
     df.drop(delList, axis=1, inplace=True)
-#     columnRename(df, [
-#                 ['CON레벨센서', 'CON레벨A']
-#                 , ['CON레벨센서2', 'CON레벨B'])
+#     columnRename(df, [['c1_p', 'c1_a'] , ['c2_p', 'c2_a']])
+
+
+def normalization(t, type = 0):
+    if type == 0:
+        return t / t.max()
+    elif type == 1:
+        return t / t.min()
\ No newline at end of file
