@@ -5,7 +5,7 @@ import time
 import pynvml
 
 class GPU_Worker():
-    def __init__(self, gpus = [], waitTimeInit = 30, waitTime = 60,
+    def __init__(self, gpus = [], waitTimeInit = 30, waitTime = 60, count = 0,
                  checkType:int = 0, utilRatio:int = 50, need_gpu=1, reversed=False, p = True):
         self.activate  = False
         self.gpus      = gpus
@@ -17,22 +17,23 @@ class GPU_Worker():
         self.reversed  = reversed
         self.utilRatio = utilRatio
         self.p = p
+        self.count = count
 
         self.availGPUs = []
 
     def getFreeRatio(self, id):
         handle = pynvml.nvmlDeviceGetHandleByIndex(id)
         use = pynvml.nvmlDeviceGetUtilizationRates(handle)
-        # ratio = 0.5 * (float(use.gpu + float(use.memory)))
+        ratio = 0.5 * (float(use.gpu + float(use.memory)))
         # ratio = float(use.memory)
-        ratio = float(use.gpu)
+        # ratio = float(use.gpu)
         return ratio
 
     def setGPU(self):
         if self.activate: time.sleep(self.waitTimeInit)
         else: self.activate = True
 
-        count = 0
+        count = self.count
         pynvml.nvmlInit()
         while True:
             availGPUs = []
